@@ -2,14 +2,14 @@ from __future__ import annotations
 
 from functools import update_wrapper
 from json import JSONDecoder, JSONEncoder
-from typing import Callable, Iterable, List, Optional, Type, TYPE_CHECKING, Union
+from typing import Any, Callable, Iterable, List, Optional, Type, TYPE_CHECKING, Union
 
 from .static import PackageStatic
 
 if TYPE_CHECKING:
     from .app import Quart  # noqa
 
-DeferedSetupFunction = Callable[["BlueprintSetupState"], Callable]
+DeferredSetupFunction = Callable[["BlueprintSetupState"], Callable]
 
 
 class Blueprint(PackageStatic):
@@ -18,7 +18,7 @@ class Blueprint(PackageStatic):
     The application properties include routes, error handlers, and
     before and after request functions. It is useful to produce
     modular code as it allows the properties to be defined in a
-    blueprint thereby defering the addition of these properties to the
+    blueprint thereby deferring the addition of these properties to the
     app.
 
     Attributes:
@@ -44,17 +44,22 @@ class Blueprint(PackageStatic):
         template_folder: Optional[str] = None,
         url_prefix: Optional[str] = None,
         subdomain: Optional[str] = None,
+        url_defaults: Optional[dict] = None,
         root_path: Optional[str] = None,
+        **kwargs: Any,
     ) -> None:
         super().__init__(import_name, template_folder, root_path, static_folder, static_url_path)
         self.name = name
         self.url_prefix = url_prefix
-        self.deferred_functions: List[DeferedSetupFunction] = []
+        self.deferred_functions: List[DeferredSetupFunction] = []
         self.subdomain = subdomain
+        if url_defaults is None:
+            url_defaults = {}
+        self.url_values_defaults = url_defaults
 
     def route(
         self,
-        path: str,
+        rule: str,
         methods: Optional[List[str]] = None,
         endpoint: Optional[str] = None,
         defaults: Optional[dict] = None,
@@ -79,10 +84,10 @@ class Blueprint(PackageStatic):
 
         def decorator(func: Callable) -> Callable:
             self.add_url_rule(
-                path,
+                rule,
                 endpoint,
                 func,
-                methods,
+                methods=methods,
                 defaults=defaults,
                 host=host,
                 subdomain=subdomain,
@@ -95,14 +100,14 @@ class Blueprint(PackageStatic):
 
     def add_url_rule(
         self,
-        path: str,
+        rule: str,
         endpoint: Optional[str] = None,
         view_func: Optional[Callable] = None,
+        *,
         methods: Optional[Iterable[str]] = None,
         defaults: Optional[dict] = None,
         host: Optional[str] = None,
         subdomain: Optional[str] = None,
-        *,
         provide_automatic_options: Optional[bool] = None,
         is_websocket: bool = False,
         strict_slashes: Optional[bool] = None,
@@ -126,13 +131,13 @@ class Blueprint(PackageStatic):
             raise ValueError("Blueprint endpoints should not contain periods")
         self.record(
             lambda state: state.add_url_rule(
-                path,
+                rule,
                 endpoint,
                 view_func,
-                methods,
-                defaults,
-                host,
-                self.subdomain,
+                methods=methods,
+                defaults=defaults,
+                host=host,
+                subdomain=subdomain or self.subdomain,
                 provide_automatic_options=provide_automatic_options,
                 is_websocket=is_websocket,
                 strict_slashes=strict_slashes,
@@ -141,7 +146,7 @@ class Blueprint(PackageStatic):
 
     def websocket(
         self,
-        path: str,
+        rule: str,
         endpoint: Optional[str] = None,
         defaults: Optional[dict] = None,
         host: Optional[str] = None,
@@ -164,7 +169,7 @@ class Blueprint(PackageStatic):
 
         def decorator(func: Callable) -> Callable:
             self.add_websocket(
-                path,
+                rule,
                 endpoint,
                 func,
                 defaults=defaults,
@@ -178,7 +183,7 @@ class Blueprint(PackageStatic):
 
     def add_websocket(
         self,
-        path: str,
+        rule: str,
         endpoint: Optional[str] = None,
         view_func: Optional[Callable] = None,
         defaults: Optional[dict] = None,
@@ -202,10 +207,10 @@ class Blueprint(PackageStatic):
             blueprint.add_websocket('/', route)
         """
         return self.add_url_rule(
-            path,
+            rule,
             endpoint,
             view_func,
-            {"GET"},
+            methods={"GET"},
             defaults=defaults,
             host=host,
             subdomain=subdomain,
@@ -725,11 +730,11 @@ class Blueprint(PackageStatic):
         self.record_once(lambda state: state.app.url_defaults(func))
         return func
 
-    def record(self, func: DeferedSetupFunction) -> None:
+    def record(self, func: DeferredSetupFunction) -> None:
         """Used to register a deferred action."""
         self.deferred_functions.append(func)
 
-    def record_once(self, func: DeferedSetupFunction) -> None:
+    def record_once(self, func: DeferredSetupFunction) -> None:
         """Used to register a deferred action that happens only once."""
 
         def wrapper(state: "BlueprintSetupState") -> None:
@@ -738,18 +743,17 @@ class Blueprint(PackageStatic):
 
         self.record(update_wrapper(wrapper, func))
 
-    def register(
-        self,
-        app: "Quart",
-        first_registration: bool,
-        *,
-        url_prefix: Optional[str] = None,
-        subdomain: Optional[str] = None,
-    ) -> None:
-        """Register this blueprint on the app given."""
-        state = self.make_setup_state(
-            app, first_registration, url_prefix=url_prefix, subdomain=subdomain
-        )
+    def register(self, app: "Quart", options: dict, first_registration: bool = False) -> None:
+        """Register this blueprint on the app given.
+
+        Arguments:
+            app: The application this blueprint is being registered with.
+            options: Keyword arguments forwarded from
+                :meth:`~quart.Quart.register_blueprint`.
+            first_registration: Whether this is the first time this
+                blueprint has been registered on the application.
+        """
+        state = self.make_setup_state(app, options, first_registration)
 
         if self.has_static_folder:
             state.add_url_rule(
@@ -762,23 +766,19 @@ class Blueprint(PackageStatic):
             func(state)
 
     def make_setup_state(
-        self,
-        app: "Quart",
-        first_registration: bool,
-        *,
-        url_prefix: Optional[str] = None,
-        subdomain: Optional[str] = None,
+        self, app: "Quart", options: dict, first_registration: bool = False
     ) -> "BlueprintSetupState":
         """Return a blueprint setup state instance.
 
         Arguments:
             first_registration: True if this is the first registration
                 of this blueprint on the app.
-            url_prefix: An optional prefix to all rules
+            options: Keyword arguments forwarded from
+                :meth:`~quart.Quart.register_blueprint`.
+            first_registration: Whether this is the first time this
+                blueprint has been registered on the application.
         """
-        return BlueprintSetupState(
-            self, app, first_registration, url_prefix=url_prefix, subdomain=subdomain
-        )
+        return BlueprintSetupState(self, app, options, first_registration)
 
 
 class BlueprintSetupState:
@@ -794,31 +794,27 @@ class BlueprintSetupState:
     """
 
     def __init__(
-        self,
-        blueprint: Blueprint,
-        app: "Quart",
-        first_registration: bool,
-        *,
-        subdomain: Optional[str] = None,
-        url_prefix: Optional[str] = None,
+        self, blueprint: Blueprint, app: "Quart", options: dict, first_registration: bool
     ) -> None:
         self.blueprint = blueprint
         self.app = app
-        self.url_prefix = url_prefix or self.blueprint.url_prefix
+        self.options = options
+        self.url_prefix = options.get("url_prefix") or blueprint.url_prefix
         self.first_registration = first_registration
-        if subdomain is None:
-            self.subdomain = blueprint.subdomain
+        self.subdomain = options.get("subdomain") or blueprint.subdomain
+        self.url_defaults = dict(self.blueprint.url_values_defaults)
+        self.url_defaults.update(options.get("url_defaults", {}) or {})
 
     def add_url_rule(
         self,
         path: str,
         endpoint: Optional[str] = None,
         view_func: Optional[Callable] = None,
+        *,
         methods: Optional[Iterable[str]] = None,
         defaults: Optional[dict] = None,
         host: Optional[str] = None,
         subdomain: Optional[str] = None,
-        *,
         provide_automatic_options: Optional[bool] = None,
         is_websocket: bool = False,
         strict_slashes: Optional[bool] = None,
@@ -828,15 +824,18 @@ class BlueprintSetupState:
         if subdomain is None:
             subdomain = self.subdomain
         endpoint = f"{self.blueprint.name}.{endpoint}"
+        url_defaults = self.url_defaults
+        if defaults is not None:
+            url_defaults = {**url_defaults, **defaults}
         self.app.add_url_rule(
             path,
             endpoint,
             view_func,
-            methods,
-            defaults,
+            provide_automatic_options=provide_automatic_options,
+            methods=methods,
+            defaults=url_defaults,
             host=host,
             subdomain=subdomain,
-            provide_automatic_options=provide_automatic_options,
             is_websocket=is_websocket,
             strict_slashes=strict_slashes,
         )
